pub struct Storage {
pub pins: CoMap<String, Pin>,
pub blocks: CoMap<WeakCid, BlockMetadata>,
pub blocks_index_unreferenced: CoMap<WeakCid, BlockInfo>,
pub block_structure_pending: CoMap<WeakCid, BlockStructurePending>,
}Fields
pins: CoMap<String, Pin>Named pins.
blocks: CoMap<WeakCid, BlockMetadata>Block metadata.
blocks_index_unreferenced: CoMap<WeakCid, BlockInfo>Block metadata index to unreferenced (reference count of zero and children resolved) entries.
See: BlockMetadata::is_removable
block_structure_pending: CoMap<WeakCid, BlockStructurePending>Blocks that are recursively added but children are pending. Blocks that are recursively deleted but children has not yet unreferenced.
Implementations
Sourceimpl Storage
impl Storage
Sourcepub async fn initial_state<S: BlockStorage + Clone + 'static>(
storage: &S,
actions: Vec<StorageAction>,
) -> Result<OptionLink<Self>, Error>
pub async fn initial_state<S: BlockStorage + Clone + 'static>( storage: &S, actions: Vec<StorageAction>, ) -> Result<OptionLink<Self>, Error>
Create inital state.