pub enum StorageAction {
Show 13 variants
Reference(BlockInfo, References),
Unreference(BlockInfo, References),
Structure(BTreeMap<WeakCid, References>),
ReferenceCreate(BlockInfo, References),
Remove(BlockInfo, BTreeSet<WeakCid>, bool),
Delete(BlockInfo, BTreeMap<WeakCid, BTreeSet<WeakCid>>, bool),
TagsInsert(BTreeSet<WeakCid>, Tags),
TagsRemove(BTreeSet<WeakCid>, Tags),
PinCreate(String, PinStrategy, References),
PinUpdate(String, PinStrategy),
PinReference(String, References),
PinRemove(String),
Batch(CoList<StorageAction>),
}Variants
Reference(BlockInfo, References)
Increase [Cid] reference count by one.
Refernces are creates on-the-fly if not exist.
Shallow: [Cid] links are not added automatically (not recusrive).
Args
- BlockInfo contains causality data about the reference
- The blocks to reference
- Tags will be merged with
BlockMetadata::tags
Unreference(BlockInfo, References)
Decrease [Cid] reference count by one.
Structure(BTreeMap<WeakCid, References>)
Structurally reference/delete [Cid].
Expects all children references passed for a parent even is they not exist on disk.
Vec Arguments
0: The parent reference.1: The links of the parent reference.
ReferenceCreate(BlockInfo, References)
Create [Cid] references with ref count of zero if the reference not exists yet.
This is normally used to track newly created blocks.
Arguments
0: The [Cid] of entries to create.
Remove(BlockInfo, BTreeSet<WeakCid>, bool)
Mark to remove [Cid]. This will make the references shallow again.
And eventually shedule them to delete.
Note
This is basically the same as Unreference.
Arguments
0: The BlockInfo of the blocks to remove.0: The [Cid] of entries to remove.1: Force remove all instances.
Delete(BlockInfo, BTreeMap<WeakCid, BTreeSet<WeakCid>>, bool)
Delete [Cid] references.
Arguments
0: The [Cid] of entries to remove with all of its direct children.1: Force delete. If false only references with a zero ref count will be removed.
TagsInsert(BTreeSet<WeakCid>, Tags)
Append tags to references.
TagsRemove(BTreeSet<WeakCid>, Tags)
Remove tags from references.
PinCreate(String, PinStrategy, References)
Create a named pin and reference all specified [Cid]s.
PinUpdate(String, PinStrategy)
Update a named pin by setting the PinStrategy.
PinReference(String, References)
Insert references to a named pin and reference all specified [Cid]s.
PinRemove(String)
Remove a named pin and unreference all [Cid]s.
Batch(CoList<StorageAction>)
Batch process actions.